#[repr(C)]pub struct FanGetFanLevelResponse {
pub status: i32,
pub fan_level: u32,
}Fields
status: i32fan_level: u32Trait Implementations
Sourceimpl Clone for FanGetFanLevelResponse
impl Clone for FanGetFanLevelResponse
Sourcefn clone(&self) -> FanGetFanLevelResponse
fn clone(&self) -> FanGetFanLevelResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FanGetFanLevelResponse
Sourceimpl Debug for FanGetFanLevelResponse
impl Debug for FanGetFanLevelResponse
Sourceimpl<D: ResourceDialect> Decode<FanGetFanLevelResponse, D> for FanGetFanLevelResponse
impl<D: ResourceDialect> Decode<FanGetFanLevelResponse, D> for FanGetFanLevelResponse
Sourceimpl<D: ResourceDialect> Encode<FanGetFanLevelResponse, D> for &FanGetFanLevelResponse
impl<D: ResourceDialect> Encode<FanGetFanLevelResponse, D> for &FanGetFanLevelResponse
Sourceimpl<D: ResourceDialect, T0: Encode<i32, D>, T1: Encode<u32, D>> Encode<FanGetFanLevelResponse, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<i32, D>, T1: Encode<u32, D>> Encode<FanGetFanLevelResponse, D> for (T0, T1)
impl Eq for FanGetFanLevelResponse
Sourceimpl Hash for FanGetFanLevelResponse
impl Hash for FanGetFanLevelResponse
Sourceimpl Ord for FanGetFanLevelResponse
impl Ord for FanGetFanLevelResponse
Sourcefn cmp(&self, other: &FanGetFanLevelResponse) -> Ordering
fn cmp(&self, other: &FanGetFanLevelResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FanGetFanLevelResponse
impl PartialEq for FanGetFanLevelResponse
Sourcefn eq(&self, other: &FanGetFanLevelResponse) -> bool
fn eq(&self, other: &FanGetFanLevelResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FanGetFanLevelResponse
impl PartialOrd for FanGetFanLevelResponse
impl Persistable for FanGetFanLevelResponse
impl StructuralPartialEq for FanGetFanLevelResponse
Sourceimpl TypeMarker for FanGetFanLevelResponse
impl TypeMarker for FanGetFanLevelResponse
Sourcetype Owned = FanGetFanLevelResponse
type Owned = FanGetFanLevelResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for FanGetFanLevelResponse
impl ValueTypeMarker for FanGetFanLevelResponse
Sourcetype Borrowed<'a> = &'a FanGetFanLevelResponse
type Borrowed<'a> = &'a FanGetFanLevelResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for FanGetFanLevelResponse
impl RefUnwindSafe for FanGetFanLevelResponse
impl Send for FanGetFanLevelResponse
impl Sync for FanGetFanLevelResponse
impl Unpin for FanGetFanLevelResponse
impl UnsafeUnpin for FanGetFanLevelResponse
impl UnwindSafe for FanGetFanLevelResponse