#[repr(C)]pub struct FanSetFanLevelRequest {
pub fan_level: u32,
}Fields
fan_level: u32Trait Implementations
Sourceimpl Clone for FanSetFanLevelRequest
impl Clone for FanSetFanLevelRequest
Sourcefn clone(&self) -> FanSetFanLevelRequest
fn clone(&self) -> FanSetFanLevelRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FanSetFanLevelRequest
Sourceimpl Debug for FanSetFanLevelRequest
impl Debug for FanSetFanLevelRequest
Sourceimpl<D: ResourceDialect> Decode<FanSetFanLevelRequest, D> for FanSetFanLevelRequest
impl<D: ResourceDialect> Decode<FanSetFanLevelRequest, D> for FanSetFanLevelRequest
Sourceimpl<D: ResourceDialect> Encode<FanSetFanLevelRequest, D> for &FanSetFanLevelRequest
impl<D: ResourceDialect> Encode<FanSetFanLevelRequest, D> for &FanSetFanLevelRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>> Encode<FanSetFanLevelRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u32, D>> Encode<FanSetFanLevelRequest, D> for (T0,)
impl Eq for FanSetFanLevelRequest
Sourceimpl Hash for FanSetFanLevelRequest
impl Hash for FanSetFanLevelRequest
Sourceimpl Ord for FanSetFanLevelRequest
impl Ord for FanSetFanLevelRequest
Sourcefn cmp(&self, other: &FanSetFanLevelRequest) -> Ordering
fn cmp(&self, other: &FanSetFanLevelRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FanSetFanLevelRequest
impl PartialEq for FanSetFanLevelRequest
Sourcefn eq(&self, other: &FanSetFanLevelRequest) -> bool
fn eq(&self, other: &FanSetFanLevelRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FanSetFanLevelRequest
impl PartialOrd for FanSetFanLevelRequest
impl Persistable for FanSetFanLevelRequest
impl StructuralPartialEq for FanSetFanLevelRequest
Sourceimpl TypeMarker for FanSetFanLevelRequest
impl TypeMarker for FanSetFanLevelRequest
Sourcetype Owned = FanSetFanLevelRequest
type Owned = FanSetFanLevelRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for FanSetFanLevelRequest
impl ValueTypeMarker for FanSetFanLevelRequest
Sourcetype Borrowed<'a> = &'a FanSetFanLevelRequest
type Borrowed<'a> = &'a FanSetFanLevelRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for FanSetFanLevelRequest
impl RefUnwindSafe for FanSetFanLevelRequest
impl Send for FanSetFanLevelRequest
impl Sync for FanSetFanLevelRequest
impl Unpin for FanSetFanLevelRequest
impl UnsafeUnpin for FanSetFanLevelRequest
impl UnwindSafe for FanSetFanLevelRequest